@@ -2,7 +2,7 @@ from pythautomata.base_types.state import State
 from pythautomata.base_types.symbol import SymbolStr
 from pythautomata.base_types.alphabet import Alphabet
 from pythautomata.automata.non_deterministic_finite_automaton import NondeterministicFiniteAutomaton as NFA
-from pythautomata.model_comparators.hopcroft_karp_comparison_strategy import HopcroftKarpComparisonStrategy as NFAComparator
+from pythautomata.model_comparators.hopcroft_karp_comparison_strategy import HopcroftKarpComparisonStrategy as HopcroftKarpComparison
 from pythautomata.utilities.automata_converter import AutomataConverter
 
 abAlphabet = Alphabet(frozenset((SymbolStr('a'), SymbolStr('b'))))
@@ -53,7 +53,7 @@ class SampleNFAs:
         state3.add_transition(b, state0)
         state4.add_transition(a, state4)
         state4.add_transition(b, state4)
-        comparator = NFAComparator()
+        comparator = HopcroftKarpComparison()
         return NFA(abAlphabet, frozenset({state0}),
                    set([state0, state1,
                         state2, state3, state4]),
@@ -84,7 +84,7 @@ class SampleNFAs:
         state4.add_transition(b, state4)
         state5.add_transition(a, state5)
         state5.add_transition(b, state5)
-        comparator = NFAComparator()
+        comparator = HopcroftKarpComparison()
         return NFA(abAlphabet, frozenset({state0}),
                    set([state0, state1, state2,
                         state3, state4, state5]),
@@ -118,7 +118,7 @@ class SampleNFAs:
         state3.add_transition(b, state3)
         state3.add_transition(c, state2)
 
-        comparator = NFAComparator()
+        comparator = HopcroftKarpComparison()
         result = NFA(abcAlphabet, frozenset({state0, state2}),
                      set([state0, state1, state2, state3]),
                      comparator,
@@ -147,7 +147,7 @@ class SampleNFAs:
         state3.add_transition(b, state2)
         state4.add_transition(a, state4)
         state4.add_transition(b, state4)
-        comparator = NFAComparator()
+        comparator = HopcroftKarpComparison()
         return NFA(abAlphabet, frozenset({state0}),
                    set([state0, state1, state2, state3, state4]),
                    comparator,
@@ -181,7 +181,7 @@ class SampleNFAs:
         state7.add_transition(b, state8)
         state8.add_transition(b, state6)
         state9.add_transition(b, state9)
-        comparator = NFAComparator()
+        comparator = HopcroftKarpComparison()
         return NFA(abAlphabet, frozenset({state0}),
                    set([state0, state1, state2, state3, state4,
                         state5, state6, state7, state8, state9]),
@@ -207,7 +207,7 @@ class SampleNFAs:
         state3.add_transition(a, state5)
         state3.add_transition(b, state4)
         state4.add_transition(a, state5)
-        comparator = NFAComparator()
+        comparator = HopcroftKarpComparison()
         return NFA(abAlphabet, frozenset({state0}),
                    set([state0, state1, state2,
                         state3, state4, state5, state6]),
